@@ -1,21 +1,34 @@
-from latin.a_global import *
-import copy,os
+import copy,os, sys
+public = 1
+
+
 '''
+make sure public is set to 1, when I code for myself
+the general functions folder is used for all of my separate
+projects, but since that would confuse other people only
+those functions relevant to this project are used.
+
 unidecode2 must be used because unidecode changes
 ȳ to u
 '''
 
-from latin.unidecode2 import unidecode
+from unidecode2 import unidecode
 from collections import defaultdict
-if not public:
-    from general import *
-    lfold = f'{vol}documents/pcode/latin/latin/'
-else:
-    from latin.general_la import *
-    lfold = ''
-
 vol = os.path.join(os.path.dirname(__file__)) + '/general_la/'
 
+if not public:
+    vol2 = '/users/kylefoley/'
+    gen_dir = f'{vol2}documents/pcode'
+    if not os.path.exists(gen_dir):
+        assert 0, 'my mistake the public variable needs to be set to 1'
+
+    sys.path.append(gen_dir)
+    from general import *
+    lfold = f'{vol2}documents/pcode/latin/latin/'
+else:
+    from general_la import *
+    lfold = ''
+
 fold = f'{vol}files/'
 bfold = f'old/old_files/'
 lafold = f'{vol}lasla/'
@@ -665,3 +678,5 @@ class decline:
                     self.suf[n].add(w)
             for x,y in self.suf.items():
                 self.suf[x] = list(y)
+
+bb=8
\ No newline at end of file
