@@ -1,4 +1,4 @@
-from latin.bglobals import *
+from bglobals import *
 
 
 class top_most:
@@ -14,9 +14,9 @@ class top_most:
             self.short = 0
             self.jv = JVReplacer()
             self.alemmas = defaultdict(dict)
-            self.lemmas = pi.open_pickle(f'{fold}clemmas1a', 1)
+            self.co_lemmas1a = pi.open_pickle(f'{fold}co_lemmas1a', 1)
             self.old2new_mods = pi.open_pickle(f'{fold}old2new_mods', 1)
-            for k, v in self.lemmas.items():
+            for k, v in self.co_lemmas1a.items():
                 v['macron'] = ""
             self.lat_freq = pi.open_pickle(f'{fold}latin_freq', 1)
             lst = []
@@ -36,7 +36,7 @@ class top_most:
             self.form = 'geninf'
         else:
             self.form = 'perf'
-        for k, v in self.lemmas.items():
+        for k, v in self.co_lemmas1a.items():
             v[f'{self.form}m'] = []
         self.diph = ['ae', 'au', 'ei', 'eu', 'oe', 'ui']
 
@@ -46,7 +46,7 @@ class top_most:
         if kind == 6:
             pi.save_pickle(self.stan2alt, f'{fold}stan2alt_spell', 1)
         if kind == 2:
-            pi.save_pickle(self.lemmas, f'{fold}co_lemmas2', 1)
+            pi.save_pickle(self.co_lemmas1a, f'{fold}co_lemmas2', 1)
         if kind == 9:
             pi.save_pickle(self.col_dct, f'{fold}col_dct', 1)
         return
@@ -59,29 +59,29 @@ class step_three(top_most):
     def quick_fix(self):
         if self.kind2 == 'e':
             return
-        for k, v in self.lemmas.items():
+        for k, v in self.co_lemmas1a.items():
             if k == 'crebresco':
                 bb = 8
 
             if v['geninfm']:
                 lst = [x for x in v['geninfm'] if not reg(r'[\)\(\-#]', x)]
                 v['geninfm'] = lst
-                self.lemmas[k] = v
+                self.co_lemmas1a[k] = v
             if v['perfm']:
                 lst = [x for x in v['perfm'] if not reg(r'[\)\(\-#]', x)]
                 v['perfm'] = lst
-                self.lemmas[k] = v
+                self.co_lemmas1a[k] = v
 
     def fdiph_fu(self, med=0):
         if med:
-            self.lemmas = pi.open_pickle(f'{fold}flemmas', 1)
+            self.co_lemmas1a = pi.open_pickle(f'{fold}flemmas', 1)
             self.quick_fix()
             self.i2j = pi.open_pickle(f'{fold}i2j', 1)
         if not self.debug and not self.kind2 in ['e', 'f']:
-            self.lemmas['nereides']['geninfm'] = ['nēried']
-            self.lemmas['adrastis']['geninfm'] = ['ādrastid']
-            self.lemmas['aeetias']['geninfm'] = ['aeētiad']
-            self.lemmas['sanguinans']['geninfm'] = ['sanguinānt']
+            self.co_lemmas1a['nereides']['geninfm'] = ['nēried']
+            self.co_lemmas1a['adrastis']['geninfm'] = ['ādrastid']
+            self.co_lemmas1a['aeetias']['geninfm'] = ['aeētiad']
+            self.co_lemmas1a['sanguinans']['geninfm'] = ['sanguinānt']
 
         self.counts = 0
         self.tjv = set()
@@ -90,7 +90,7 @@ class step_three(top_most):
         if self.kind2 == 'e':
             lemmas = self.alemmas
         else:
-            lemmas = self.lemmas
+            lemmas = self.co_lemmas1a
 
         auth_list = ['LS', 'GG', 'GJ', 'Ge', 'Lw', 'YO', 'PO']
         b =0
@@ -302,7 +302,7 @@ class step_two(step_three):
 
         for k, v in self.lem2part.items():  # todo put an interval here
             # p (k)
-            lemma = self.lemmas[k]
+            lemma = self.co_lemmas1a[k]
             geninf = lemma[form]
             if geninf:
                 c += 1
@@ -377,7 +377,7 @@ class step_two(step_three):
                     if not self.second:
                         lem = new_lem2(k)
                         lem['lemma'] = z[2]
-                        obj2 = self.lemmas[k]
+                        obj2 = self.co_lemmas1a[k]
                         lem['lexicon'] = obj2['lexicon']
                         lem['quantity'] = ""
                         lem['model'] = obj2['model']
@@ -437,7 +437,7 @@ class step_two(step_three):
 
             dct = defaultdict(dict)
             for k, v in self.alemmas.items():
-                lem = self.lemmas.get(k)
+                lem = self.co_lemmas1a.get(k)
                 if lem:
                     for l in ['geninf', 'perf']:
                         s = lem.get('o' + l)
@@ -544,7 +544,7 @@ class step_two(step_three):
                 vgf.print_intervals(b,200,None,len(self.lem2part3))
             for x, y in v.items():
                 if y[-1] == 0 and y[1]:
-                    lemma = self.lemmas.get(k)
+                    lemma = self.co_lemmas1a.get(k)
                     lemma = lemma['lemma']
                     lemma_mac = self.disg2[lemma][x]
                     if k == 'coerceo':
@@ -645,7 +645,7 @@ class step_two(step_three):
         return x
 
     def stem_head(self, k, v):
-        olem = self.lemmas[k]
+        olem = self.co_lemmas1a[k]
         s = olem[f'o{self.form}'].lower()
         s = s.replace(cobr, '')
         alt = self.stan2alt.get(k)
@@ -833,7 +833,7 @@ class step_one(step_two):
         # and perf stems because collatinus treats āe to mean that
         # the diphthong ae is long
 
-        for k, v in self.lemmas.items():
+        for k, v in self.co_lemmas1a.items():
             if v['geninf']:
                 g = v['geninf']
                 if g == '-':
@@ -1010,11 +1010,11 @@ class step_one(step_two):
         b = 0
         for k, v in self.col_dct.items():
             k1 = jv.replace(k)
-            if k1 in self.lemmas:
+            if k1 in self.co_lemmas1a:
                 dct[k1] = v
 
         self.col_dct = dct
-        self.lemmas = {k: v for k, v in self.lemmas.items() if k in self.col_dct}
+        self.co_lemmas1a = {k: v for k, v in self.co_lemmas1a.items() if k in self.col_dct}
         return
 
     def fix_po(self):
@@ -1078,7 +1078,7 @@ class step_one(step_two):
         return x
 
     def research_ostem(self, k):
-        if self.lemmas[k].get('ogeninf') or self.lemmas[k].get('operf'):
+        if self.co_lemmas1a[k].get('ogeninf') or self.co_lemmas1a[k].get('operf'):
             return 1
 
     # def redundant_stems(self):
@@ -1135,7 +1135,7 @@ class step_one(step_two):
         else:
             form = 'geninf'
         for k, v in self.lem2part.items():
-            lemma = self.lemmas.get(k)
+            lemma = self.co_lemmas1a.get(k)
             if lemma[form] and lemma['model'] not in greek_models() \
                     and k not in excep:
                 s = lemma[form]
@@ -1280,7 +1280,7 @@ class step_one(step_two):
             wrds = set()
             dct4 = {}
             dct5 = {}
-            lemma = self.lemmas[k]
+            lemma = self.co_lemmas1a[k]
             beg = 0
             for i in lst:
                 if len(v[i]) > 2:
@@ -1317,7 +1317,7 @@ class step_one(step_two):
 
 
         dct = {}
-        for k, v in self.lemmas.items():
+        for k, v in self.co_lemmas1a.items():
             if not v['macron']:
                 dct[k] = v
                 p(k)
@@ -1694,7 +1694,7 @@ class step_one(step_two):
                     # self.macrons[str1_wo_mac][lemma] = str1
                     lem2word[lemma].add(str1)
             for k, t in lem2word.items():
-                lem = self.lemmas[k]
+                lem = self.co_lemmas1a[k]
                 assert len(lem2bod[k]) == 1
                 lem[self.form + 'm'] += list(t)
             # p (k, t)
@@ -1718,7 +1718,7 @@ class step_one(step_two):
             enough info has been given regarding their vowel quantity
             '''
         ]
-        for k, v in self.lemmas.items():
+        for k, v in self.co_lemmas1a.items():
             st1 = set(v[f'{self.form}m'])
             dctm = {unidecode(x): x for x in st1}
             st2 = set(dctm.keys())
@@ -1763,7 +1763,7 @@ class step_one(step_two):
         for i in range(2):
             if i:
                 dct = {}
-            for x, y in self.lemmas.items():
+            for x, y in self.co_lemmas1a.items():
                 if y[self.form]:
                     lst = y[f'{self.form}m']
                     lst = [unidecode(x) for x in lst]
