@@ -1,6 +1,6 @@
 import subprocess
-from latin.general_la.abbreviations import *
-import latin.general_la.very_general_functions as vgf
+from abbreviations import *
+import very_general_functions as vgf
 
 
 
