@@ -1,11 +1,10 @@
 from collections import ChainMap
-from latin.bglobals import *
+from bglobals import *
 if not public:
-    from latin.i_scrape_old import old_entry
-from latin.j_lasla import convert2txt
-from latin.c_colat4 import bottom_most_a4
+    from i_scrape_old import old_entry
+from j_lasla import convert2txt
+from c_colat4 import bottom_most_a4
 
-lafold = f'{lfold}lasla/'
 
 '''
 occido3 = occidoō
